==> haskell-hls-module-name-plugin-2.1.0.0-59-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-module-name-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-module-name-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-module-name-plugin-2.1.0.0-CVnK3lFs1Ck5lFzu5BuDba
key:                  hls-module-name-plugin-2.1.0.0-CVnK3lFs1Ck5lFzu5BuDba
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Module name plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  28acb12933f128f104de5ae5e8052d74
exposed:              True
exposed-modules:      Ide.Plugin.ModuleName
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-module-name-plugin
hs-libraries:         HShls-module-name-plugin-2.1.0.0-CVnK3lFs1Ck5lFzu5BuDba
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1 containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2
    ghcide-2.1.0.0-7mveeBu1NdO3tDaPLTwSr0
    hls-plugin-api-2.1.0.0-2mMBQBjk997A47exxFPkZd
    lsp-2.1.0.0-GxokUjVxBLy4j05JlhgdFg text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk

haddock-interfaces:
    /usr/share/doc/haskell-hls-module-name-plugin/html/hls-module-name-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-module-name-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-module-name-plugin-2.1.0.0-94-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-module-name-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-module-name-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-module-name-plugin-2.1.0.0-5mjMWMZ3GI2KnjEIUDY14l
key:                  hls-module-name-plugin-2.1.0.0-5mjMWMZ3GI2KnjEIUDY14l
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Module name plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  48903c72f9f80672d86ee4f44addc1c6
exposed:              True
exposed-modules:      Ide.Plugin.ModuleName
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-module-name-plugin
hs-libraries:         HShls-module-name-plugin-2.1.0.0-5mjMWMZ3GI2KnjEIUDY14l
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1 containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2
    ghcide-2.1.0.0-EGobQkKgR8zaeADYgxOC5
    hls-plugin-api-2.1.0.0-EfBvd6pBF3is65S9wzuFu
    lsp-2.1.0.0-4wEItkatDyfAFCzTPH6SAN text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM

haddock-interfaces:
    /usr/share/doc/haskell-hls-module-name-plugin/html/hls-module-name-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-module-name-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
